@@ -7,8 +7,7 @@ import numpy as np
 from .utils import readToGray
 from .utils import saveNumpy
 
-# def preprocess(DIR, categories, resized_size=None, train_size, name, isSave=True):
-def preprocess(DIR, categories, resized_size=None, train_size, name):
+def preprocess(DIR, classes, name, resized_size=224, train_size=None):
     """
     Reads Images in base directory DIR
     Returns
@@ -34,7 +33,7 @@ def preprocess(DIR, categories, resized_size=None, train_size, name):
             classNum = classes.index(item)
             count = 0 
             for image in os.listdir(class_path):
-                if count != size:
+                if count != train_size:
                     image_path = os.path.join(class_path, image)
                     # Returns image RESIZED and GRAY
                     gray = readToGray(image_path, resized_size)
